==> haskell-isomorphism-class-0.1.1-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-isomorphism-class.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 isomorphism-class
version:              0.1.1
visibility:           public
id:                   isomorphism-class-0.1.1-83nIsG4ZHjE4cel6WXGLIV
key:                  isomorphism-class-0.1.1-83nIsG4ZHjE4cel6WXGLIV
license:              MIT
copyright:            (c) 2022 Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/isomorphism-class
synopsis:             Isomorphism typeclass solving the conversion problem
description:          Lawful typeclass for lossless conversion between types.
category:             Conversion
abi:                  5ea552efa426112cf3e5d13d24689de5
exposed:              True
exposed-modules:      IsomorphismClass
hidden-modules:
    IsomorphismClass.Prelude IsomorphismClass.TextCompat.Array

import-dirs:          /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-isomorphism-class
hs-libraries:         HSisomorphism-class-0.1.1-83nIsG4ZHjE4cel6WXGLIV
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.5.0-tUQ3ISdCwwAzRS3LRBhXn
    primitive-0.9.1.0-F4HGYkgYEkOLs7asiZIPNd text-2.0.2
    unordered-containers-0.2.20-Kt9XOM1GYdv4KClqugAe9a
    vector-0.13.2.0-7jLyylqham1Ij3AknS5IxU

haddock-interfaces:
    /usr/share/doc/haskell-isomorphism-class/html/isomorphism-class.haddock

haddock-html:         /usr/share/doc/haskell-isomorphism-class/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-isomorphism-class-0.1.1-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-isomorphism-class.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 isomorphism-class
version:              0.1.1
visibility:           public
id:                   isomorphism-class-0.1.1-HUgIGyX22sjFLNj9K1EiDF
key:                  isomorphism-class-0.1.1-HUgIGyX22sjFLNj9K1EiDF
license:              MIT
copyright:            (c) 2022 Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/isomorphism-class
synopsis:             Isomorphism typeclass solving the conversion problem
description:          Lawful typeclass for lossless conversion between types.
category:             Conversion
abi:                  8e6b638fedcd71ec7124faa5f4ceb6f4
exposed:              True
exposed-modules:      IsomorphismClass
hidden-modules:
    IsomorphismClass.Prelude IsomorphismClass.TextCompat.Array

import-dirs:          /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-isomorphism-class
hs-libraries:         HSisomorphism-class-0.1.1-HUgIGyX22sjFLNj9K1EiDF
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.5.0-DrXzgEMDRcV8gNOMGO5wPZ
    primitive-0.9.1.0-Jxt7FQpUmq1Ffbc4VwJGN5 text-2.0.2
    unordered-containers-0.2.20-FLM1pZb3BI5FpyNo5sVXNv
    vector-0.13.2.0-LmFi28PTaN7DJJszRwFTiC

haddock-interfaces:
    /usr/share/doc/haskell-isomorphism-class/html/isomorphism-class.haddock

haddock-html:         /usr/share/doc/haskell-isomorphism-class/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
